@@ -1,4 +1,4 @@
-## $Id: estimateNoise-methods.R 562 2011-05-26 08:56:09Z sgibb $
+## $Id: estimateNoise-methods.R 658 2011-07-20 06:46:34Z sgibb $
 ##
 ## Copyright 2011 Sebastian Gibb
 ## <mail@sebastiangibb.de>
@@ -25,8 +25,9 @@ setMethod(f="estimateNoise",
                         fun=mad,
                         ...) {
         
-    if (isEmpty(object))
-        stop("Spectrum is empty!");
+    if (.isEmptyWarning(object)) {
+        return(0);
+    }
 
     fun <- match.fun(fun);
 
